## Криволинейные координаты в пространстве. Замена переменных в тройном интеграле. Вычисление тройного интеграла в цилиндрических и сферических координатах.

### Криволинейные координаты в пространстве

Криволинейные координаты $(u, v, w)$ в пространстве определяются через декартовы координаты $(x, y, z)$ с помощью преобразования:

$$x=x(u,v,w),$$
$$y=y(u,v,w),$$
$$z=z(u,v,w).$$

Эти преобразования должны быть взаимно однозначными и непрерывно дифференцируемыми в области $V$.

### Выражение объема в криволинейных координатах

Объем элементарной области в криволинейных координатах $(u, v, w)$ выражается через якобиан преобразования:

$$dV=|J|\,du\,dv\,dw,$$

где якобиан $J$ определяется как:

$$J=\frac{\partial(x,y,z)}{\partial(u,v,w)}=\begin{vmatrix}\frac{\partial x}{\partial u}&\frac{\partial x}{\partial v}&\frac{\partial x}{\partial w}\\\frac{\partial y}{\partial u}&\frac{\partial y}{\partial v}&\frac{\partial y}{\partial w}\\\frac{\partial z}{\partial u}&\frac{\partial z}{\partial v}&\frac{\partial z}{\partial w}\end{vmatrix}.$$

### Замена переменных в тройном интеграле

Для замены переменных в тройном интеграле используется якобиан преобразования. Если $f(x, y, z)$ — функция, определенная на области $V$ в декартовых координатах, то тройной интеграл в криволинейных координатах $(u, v, w)$ выражается как:

$$\iiint_{V}f(x,y,z)\,dV=\iiint_{V'}f(x(u,v,w),y(u,v,w),z(u,v,w))|J|\,du\,dv\,dw,$$

где $V'$ — область в координатах $(u, v, w)$, соответствующая области $V$ в координатах $(x, y, z)$.

### Цилиндрические координаты

Цилиндрические координаты $(r, \theta, z)$ определяются следующим образом:

$$x=r\cos\theta,$$
$$y=r\sin\theta,$$
$$z=z.$$

Якобиан преобразования для цилиндрических координат равен:

$$J=\begin{vmatrix}\cos\theta&-r\sin\theta&0\\\sin\theta&r\cos\theta&0\\0&0&1\end{vmatrix}=r.$$

Таким образом, объем элементарной области в цилиндрических координатах выражается как:

$$dV=r\,dr\,d\theta\,dz.$$

### Вычисление тройного интеграла в цилиндрических координатах

Рассмотрим пример вычисления тройного интеграла функции $f(x, y, z) = x^2 + y^2$ по цилиндру радиуса $R$ и высоты $h$, центрированного в начале координат. В цилиндрических координатах $(r, \theta, z)$ область $V$ описывается как $0 \leq r \leq R$, $0 \leq \theta \leq 2\pi$ и $0 \leq z \leq h$. Тогда тройной интеграл можно вычислить как:

$$\iiint_{V}(x^2+y^2)\,dV=\int_{0}^{2\pi}\int_{0}^{R}\int_{0}^{h}r^2r\,dz\,dr\,d\theta.$$

Вычислим внутренний интеграл:

$$\int_{0}^{h}r^3\,dz=r^3h.$$

Теперь вычислим следующий интеграл:

$$\int_{0}^{R}r^3h\,dr=\left[\frac{r^4h}{4}\right]_{0}^{R}=\frac{R^4h}{4}.$$

И, наконец, вычислим внешний интеграл:

$$\int_{0}^{2\pi}\frac{R^4h}{4}\,d\theta=\frac{R^4h}{4}\cdot2\pi=\frac{\pi R^4h}{2}.$$

Таким образом, значение тройного интеграла равно $\frac{\pi R^4h}{2}$.

### Сферические координаты

Сферические координаты $(\rho, \theta, \phi)$ определяются следующим образом:

$$x=\rho\sin\phi\cos\theta,$$
$$y=\rho\sin\phi\sin\theta,$$
$$z=\rho\cos\phi.$$

Якобиан преобразования для сферических координат равен:

$$J=\begin{vmatrix}\sin\phi\cos\theta&\rho\cos\phi\cos\theta&-\rho\sin\phi\sin\theta\\\sin\phi\sin\theta&\rho\cos\phi\sin\theta&\rho\sin\phi\cos\theta\\\cos\phi&-\rho\sin\phi&0\end{vmatrix}=\rho^2\sin\phi.$$

Таким образом, объем элементарной области в сферических координатах выражается как:

$$dV=\rho^2\sin\phi\,d\rho\,d\theta\,d\phi.$$

### Вычисление тройного интеграла в сферических координатах

Рассмотрим пример вычисления тройного интеграла функции $f(x, y, z) = x^2 + y^2 + z^2$ по шару радиуса $R$, центрированного в начале координат. В сферических координатах $(\rho, \theta, \phi)$ область $V$ описывается как $0 \leq \rho \leq R$, $0 \leq \theta \leq 2\pi$ и $0 \leq \phi \leq \pi$. Тогда тройной интеграл можно вычислить как:

$$\iiint_{V}(x^2+y^2+z^2)\,dV=\int_{0}^{2\pi}\int_{0}^{\pi}\int_{0}^{R}\rho^2\rho^2\sin\phi\,d\rho\,d\phi\,d\theta.$$

Вычислим внутренний интеграл:

$$\int_{0}^{R}\rho^4\sin\phi\,d\rho=\left[\frac{\rho^5\sin\phi}{5}\right]_{0}^{R}=\frac{R^5\sin\phi}{5}.$$

Теперь вычислим следующий интеграл:

$$\int_{0}^{\pi}\frac{R^5\sin\phi}{5}\,d\phi=\frac{R^5}{5}\left[-\cos\phi\right]_{0}^{\pi}=\frac{2R^5}{5}.$$

И, наконец, вычислим внешний интеграл:

$$\int_{0}^{2\pi}\frac{2R^5}{5}\,d\theta=\frac{2R^5}{5}\cdot2\pi=\frac{4\pi R^5}{5}.$$

Таким образом, значение тройного интеграла равно $\frac{4\pi R^5}{5}$.