## Геометрические приложения двойных и тройных интегралов: вычисление площади плоской фигуры, вычисление объемов тел, вычисление площади поверхности.

### Вычисление площади плоской фигуры

Площадь плоской фигуры $D$ на плоскости $xy$ можно вычислить с помощью двойного интеграла. Если функция $f(x, y) = 1$, то площадь фигуры $D$ определяется как:

$$A=\iint_{D}dA=\iint_{D}dx\,dy.$$

#### Пример

Рассмотрим пример вычисления площади круга радиуса $R$, центрированного в начале координат. В полярных координатах $(r, \theta)$ область $D$ описывается как $0 \leq r \leq R$ и $0 \leq \theta \leq 2\pi$. Тогда площадь круга можно вычислить как:

$$A=\iint_{D}dA=\int_{0}^{2\pi}\int_{0}^{R}r\,dr\,d\theta.$$

Вычислим внутренний интеграл:

$$\int_{0}^{R}r\,dr=\left[\frac{r^2}{2}\right]_{0}^{R}=\frac{R^2}{2}.$$

Теперь вычислим внешний интеграл:

$$\int_{0}^{2\pi}\frac{R^2}{2}\,d\theta=\frac{R^2}{2}\cdot2\pi=\pi R^2.$$

Таким образом, площадь круга равна $\pi R^2$.

### Вычисление объемов тел

Объем тела $V$, ограниченного поверхностью $z = f(x, y)$ и проекцией этой поверхности на плоскость $xy$, можно вычислить с помощью тройного интеграла. Если $D$ — область на плоскости $xy$, то объем тела определяется как:

$$V=\iiint_{V}dV=\iint_{D}f(x,y)\,dA.$$

#### Пример

Рассмотрим пример вычисления объема тела, ограниченного поверхностью $z = x^2 + y^2$ и проекцией этой поверхности на плоскость $xy$ в пределах круга радиуса $R$, центрированного в начале координат. В полярных координатах $(r, \theta)$ область $D$ описывается как $0 \leq r \leq R$ и $0 \leq \theta \leq 2\pi$. Тогда объем тела можно вычислить как:

$$V=\iint_{D}(x^2+y^2)\,dA=\int_{0}^{2\pi}\int_{0}^{R}r^2r\,dr\,d\theta.$$

Вычислим внутренний интеграл:

$$\int_{0}^{R}r^3\,dr=\left[\frac{r^4}{4}\right]_{0}^{R}=\frac{R^4}{4}.$$

Теперь вычислим внешний интеграл:

$$\int_{0}^{2\pi}\frac{R^4}{4}\,d\theta=\frac{R^4}{4}\cdot2\pi=\frac{\pi R^4}{2}.$$

Таким образом, объем тела равен $\frac{\pi R^4}{2}$.

### Вычисление площади поверхности

Площадь поверхности $S$, заданной уравнением $z = f(x, y)$ над областью $D$ на плоскости $xy$, можно вычислить с помощью двойного интеграла. Площадь элементарной области поверхности выражается через коэффициенты частных производных функции $f(x, y)$:

$$dS=\sqrt{1+\left(\frac{\partial f}{\partial x}\right)^2+\left(\frac{\partial f}{\partial y}\right)^2}\,dA.$$

Таким образом, площадь поверхности определяется как:

$$S=\iint_{D}\sqrt{1+\left(\frac{\partial f}{\partial x}\right)^2+\left(\frac{\partial f}{\partial y}\right)^2}\,dA.$$

#### Пример

Рассмотрим пример вычисления площади поверхности, заданной уравнением $z = x^2 + y^2$ над кругом радиуса $R$, центрированного в начале координат. В полярных координатах $(r, \theta)$ область $D$ описывается как $0 \leq r \leq R$ и $0 \leq \theta \leq 2\pi$. Тогда площадь поверхности можно вычислить как:

$$S=\iint_{D}\sqrt{1+\left(\frac{\partial(x^2+y^2)}{\partial x}\right)^2+\left(\frac{\partial(x^2+y^2)}{\partial y}\right)^2}\,dA.$$

Вычислим частные производные:

$$\frac{\partial(x^2+y^2)}{\partial x}=2x,$$
$$\frac{\partial(x^2+y^2)}{\partial y}=2y.$$

Теперь подставим их в формулу для площади поверхности:

$$S=\iint_{D}\sqrt{1+4x^2+4y^2}\,dA=\int_{0}^{2\pi}\int_{0}^{R}\sqrt{1+4r^2}r\,dr\,d\theta.$$

Вычислим внутренний интеграл:

$$\int_{0}^{R}\sqrt{1+4r^2}r\,dr.$$

Для вычисления этого интеграла используем замену переменных $u = 1 + 4r^2$, тогда $du = 8r\,dr$ и $r = 0$ соответствует $u = 1$, а $r = R$ соответствует $u = 1 + 4R^2$. Тогда интеграл принимает вид:

$$\int_{1}^{1+4R^2}\frac{1}{8}\sqrt{u}\,du=\frac{1}{8}\left[\frac{2u^{3/2}}{3}\right]_{1}^{1+4R^2}=\frac{1}{12}\left((1+4R^2)^{3/2}-1\right).$$

Теперь вычислим внешний интеграл:

$$\int_{0}^{2\pi}\frac{1}{12}\left((1+4R^2)^{3/2}-1\right)\,d\theta=\frac{1}{12}\left((1+4R^2)^{3/2}-1\right)\cdot2\pi=\frac{\pi}{6}\left((1+4R^2)^{3/2}-1\right).$$

Таким образом, площадь поверхности равна $\frac{\pi}{6}\left((1+4R^2)^{3/2}-1\right)$.