## Физические приложения двойных и тройных интегралов: вычисление массы, координат центра тяжести, статических моментов тела в пространстве и плоской пластинки, моментов инерции тела в пространстве.

### Вычисление массы

Масса тела $V$ с плотностью $\rho(x, y, z)$ можно вычислить с помощью тройного интеграла:

$$M=\iiint_{V}\rho(x,y,z)\,dV.$$

#### Пример

Рассмотрим пример вычисления массы тела, заданного уравнением $z = x^2 + y^2$ над кругом радиуса $R$, центрированного в начале координат, с плотностью $\rho(x, y, z) = z$. В полярных координатах $(r, \theta)$ область $D$ описывается как $0 \leq r \leq R$ и $0 \leq \theta \leq 2\pi$. Тогда масса тела можно вычислить как:

$$M=\iiint_{V}z\,dV=\iint_{D}\left(\int_{0}^{x^2+y^2}z\,dz\right)\,dA=\int_{0}^{2\pi}\int_{0}^{R}\left(\int_{0}^{r^2}z\,dz\right)r\,dr\,d\theta.$$

Вычислим внутренний интеграл:

$$\int_{0}^{r^2}z\,dz=\left[\frac{z^2}{2}\right]_{0}^{r^2}=\frac{r^4}{2}.$$

Теперь вычислим следующий интеграл:

$$\int_{0}^{R}\frac{r^4}{2}r\,dr=\left[\frac{r^6}{12}\right]_{0}^{R}=\frac{R^6}{12}.$$

И, наконец, вычислим внешний интеграл:

$$\int_{0}^{2\pi}\frac{R^6}{12}\,d\theta=\frac{R^6}{12}\cdot2\pi=\frac{\pi R^6}{6}.$$

Таким образом, масса тела равна $\frac{\pi R^6}{6}$.

### Вычисление координат центра тяжести

Координаты центра тяжести тела $V$ с плотностью $\rho(x, y, z)$ можно вычислить с помощью тройных интегралов:

$$x_c=\frac{\iiint_{V}x\rho(x,y,z)\,dV}{\iiint_{V}\rho(x,y,z)\,dV},$$
$$y_c=\frac{\iiint_{V}y\rho(x,y,z)\,dV}{\iiint_{V}\rho(x,y,z)\,dV},$$
$$z_c=\frac{\iiint_{V}z\rho(x,y,z)\,dV}{\iiint_{V}\rho(x,y,z)\,dV}.$$

### Вычисление статических моментов

Статические моменты тела $V$ относительно плоскостей $xy$, $xz$ и $yz$ можно вычислить с помощью тройных интегралов:

$$M_{xy}=\iiint_{V}z\rho(x,y,z)\,dV,$$
$$M_{xz}=\iiint_{V}y\rho(x,y,z)\,dV,$$
$$M_{yz}=\iiint_{V}x\rho(x,y,z)\,dV.$$

### Вычисление моментов инерции

Моменты инерции тела $V$ относительно осей $x$, $y$ и $z$ можно вычислить с помощью тройных интегралов:

$$I_x=\iiint_{V}(y^2+z^2)\rho(x,y,z)\,dV,$$
$$I_y=\iiint_{V}(x^2+z^2)\rho(x,y,z)\,dV,$$
$$I_z=\iiint_{V}(x^2+y^2)\rho(x,y,z)\,dV.$$

#### Пример

Рассмотрим пример вычисления момента инерции тела, заданного уравнением $z = x^2 + y^2$ над кругом радиуса $R$, центрированного в начале координат, с плотностью $\rho(x, y, z) = 1$. В полярных координатах $(r, \theta)$ область $D$ описывается как $0 \leq r \leq R$ и $0 \leq \theta \leq 2\pi$. Тогда момент инерции относительно оси $z$ можно вычислить как:

$$I_z=\iiint_{V}(x^2+y^2)\,dV=\iint_{D}\left(\int_{0}^{x^2+y^2}(x^2+y^2)\,dz\right)\,dA=\int_{0}^{2\pi}\int_{0}^{R}\left(\int_{0}^{r^2}r^2\,dz\right)r\,dr\,d\theta.$$

Вычислим внутренний интеграл:

$$\int_{0}^{r^2}r^2\,dz=r^2\left[z\right]_{0}^{r^2}=r^4.$$

Теперь вычислим следующий интеграл:

$$\int_{0}^{R}r^4r\,dr=\left[\frac{r^6}{6}\right]_{0}^{R}=\frac{R^6}{6}.$$

И, наконец, вычислим внешний интеграл:

$$\int_{0}^{2\pi}\frac{R^6}{6}\,d\theta=\frac{R^6}{6}\cdot2\pi=\frac{\pi R^6}{3}.$$

Таким образом, момент инерции тела относительно оси $z$ равен $\frac{\pi R^6}{3}$.