## Приложения криволинейных интегралов первого рода

### Вычисление длины кривой

Длина кривой $C$, параметризованной как $(x(t), y(t), z(t))$ для $t \in [a, b]$, можно вычислить с помощью криволинейного интеграла первого рода:

$$L=\int_{C}ds=\int_{a}^{b}\sqrt{\left(\frac{dx}{dt}\right)^2+\left(\frac{dy}{dt}\right)^2+\left(\frac{dz}{dt}\right)^2}\,dt.$$

#### Пример

Рассмотрим пример вычисления длины кривой, параметризованной как $(x(t), y(t), z(t)) = (t, t^2, t^3)$ для $t \in [0, 1]$. Сначала вычислим производные:

$$\frac{dx}{dt}=1,$$
$$\frac{dy}{dt}=2t,$$
$$\frac{dz}{dt}=3t^2.$$

Теперь вычислим элемент длины дуги:

$$ds=\sqrt{\left(\frac{dx}{dt}\right)^2+\left(\frac{dy}{dt}\right)^2+\left(\frac{dz}{dt}\right)^2}\,dt=\sqrt{1+(2t)^2+(3t^2)^2}\,dt=\sqrt{1+4t^2+9t^4}\,dt.$$

Теперь подставим все в формулу криволинейного интеграла:

$$L=\int_{0}^{1}\sqrt{1+4t^2+9t^4}\,dt.$$

Для вычисления этого интеграла можно использовать численные методы или специальные функции.

### Вычисление массы проволоки

Масса проволоки, имеющей переменную линейную плотность $\rho(x, y, z)$, заданную как функция координат $(x, y, z)$, можно вычислить с помощью криволинейного интеграла первого рода:

$$M=\int_{C}\rho(x,y,z)\,ds.$$

#### Пример

Рассмотрим пример вычисления массы проволоки, параметризованной как $(x(t), y(t), z(t)) = (t, t^2, t^3)$ для $t \in [0, 1]$ с линейной плотностью $\rho(x, y, z) = x^2 + y^2 + z^2$. Сначала вычислим производные:

$$\frac{dx}{dt}=1,$$
$$\frac{dy}{dt}=2t,$$
$$\frac{dz}{dt}=3t^2.$$

Теперь вычислим элемент длины дуги:

$$ds=\sqrt{1+4t^2+9t^4}\,dt.$$

Теперь подставим все в формулу криволинейного интеграла:

$$M=\int_{0}^{1}(t^2+(t^2)^2+(t^3)^2)\sqrt{1+4t^2+9t^4}\,dt.$$

Для вычисления этого интеграла можно использовать численные методы или специальные функции.

### Вычисление центра масс

Координаты центра масс проволоки, имеющей переменную линейную плотность $\rho(x, y, z)$, можно вычислить с помощью криволинейных интегралов первого рода:

$$x_c=\frac{\int_{C}x\rho(x,y,z)\,ds}{\int_{C}\rho(x,y,z)\,ds},$$
$$y_c=\frac{\int_{C}y\rho(x,y,z)\,ds}{\int_{C}\rho(x,y,z)\,ds},$$
$$z_c=\frac{\int_{C}z\rho(x,y,z)\,ds}{\int_{C}\rho(x,y,z)\,ds}.$$

### Вычисление моментов инерции

Моменты инерции проволоки относительно осей $x$, $y$ и $z$ можно вычислить с помощью криволинейных интегралов первого рода:

$$I_x=\int_{C}(y^2+z^2)\rho(x,y,z)\,ds,$$
$$I_y=\int_{C}(x^2+z^2)\rho(x,y,z)\,ds,$$
$$I_z=\int_{C}(x^2+y^2)\rho(x,y,z)\,ds.$$

#### Пример

Рассмотрим пример вычисления момента инерции проволоки, параметризованной как $(x(t), y(t), z(t)) = (t, t^2, t^3)$ для $t \in [0, 1]$ с линейной плотностью $\rho(x, y, z) = 1$. Сначала вычислим производные:

$$\frac{dx}{dt}=1,$$
$$\frac{dy}{dt}=2t,$$
$$\frac{dz}{dt}=3t^2.$$

Теперь вычислим элемент длины дуги:

$$ds=\sqrt{1+4t^2+9t^4}\,dt.$$

Теперь подставим все в формулу криволинейного интеграла для момента инерции относительно оси $z$:

$$I_z=\int_{0}^{1}(t^2+(t^2)^2)\sqrt{1+4t^2+9t^4}\,dt.$$

Для вычисления этого интеграла можно использовать численные методы или специальные функции.