## Приложения криволинейных интегралов второго рода

### Вычисление работы

Работа, совершаемая силовым полем $\mathbf{F}(x, y, z)$ при перемещении частицы по кривой $C$, параметризованной как $(x(t), y(t), z(t))$ для $t \in [a, b]$, можно вычислить с помощью криволинейного интеграла второго рода:

$$W=\int_{C}\mathbf{F}\cdot d\mathbf{r}=\int_{C}P\,dx+Q\,dy+R\,dz,$$

где $\mathbf{F}=P\mathbf{i}+Q\mathbf{j}+R\mathbf{k}$ — векторное поле силы, а $d\mathbf{r}=dx\mathbf{i}+dy\mathbf{j}+dz\mathbf{k}$ — вектор элементарного смещения.

#### Пример

Рассмотрим пример вычисления работы, совершаемой силовым полем $\mathbf{F}(x, y, z) = y\mathbf{i} + x\mathbf{j} + z\mathbf{k}$ при перемещении частицы по кривой $C$, параметризованной как $(x(t), y(t), z(t)) = (t, t^2, t^3)$ для $t \in [0, 1]$.

Сначала вычислим производные:

$$\frac{dx}{dt}=1,$$
$$\frac{dy}{dt}=2t,$$
$$\frac{dz}{dt}=3t^2.$$

Теперь подставим все в формулу криволинейного интеграла второго рода:

$$W=\int_{0}^{1}(y\frac{dx}{dt}+x\frac{dy}{dt}+z\frac{dz}{dt})\,dt=\int_{0}^{1}(t^2\cdot1+t\cdot2t+t^3\cdot3t^2)\,dt.$$

Упростим интеграл:

$$\int_{0}^{1}(t^2+2t^2+3t^5)\,dt=\int_{0}^{1}(3t^2+3t^5)\,dt.$$

Теперь вычислим интеграл:

$$\int_{0}^{1}(3t^2+3t^5)\,dt=\left[t^3+\frac{t^6}{2}\right]_{0}^{1}=1+\frac{1}{2}=\frac{3}{2}.$$

Таким образом, работа, совершаемая силовым полем, равна $\frac{3}{2}$.

### Вычисление потока векторного поля

Поток векторного поля $\mathbf{F}(x, y, z)$ через кривую $C$ можно вычислить с помощью криволинейного интеграла второго рода:

$$\Phi=\int_{C}\mathbf{F}\cdot d\mathbf{r}=\int_{C}P\,dx+Q\,dy+R\,dz.$$

#### Пример

Рассмотрим пример вычисления потока векторного поля $\mathbf{F}(x, y, z) = y\mathbf{i} + x\mathbf{j} + z\mathbf{k}$ через кривую $C$, параметризованную как $(x(t), y(t), z(t)) = (t, t^2, t^3)$ для $t \in [0, 1]$.

Сначала вычислим производные:

$$\frac{dx}{dt}=1,$$
$$\frac{dy}{dt}=2t,$$
$$\frac{dz}{dt}=3t^2.$$

Теперь подставим все в формулу криволинейного интеграла второго рода:

$$\Phi=\int_{0}^{1}(y\frac{dx}{dt}+x\frac{dy}{dt}+z\frac{dz}{dt})\,dt=\int_{0}^{1}(t^2\cdot1+t\cdot2t+t^3\cdot3t^2)\,dt.$$

Упростим интеграл:

$$\int_{0}^{1}(t^2+2t^2+3t^5)\,dt=\int_{0}^{1}(3t^2+3t^5)\,dt.$$

Теперь вычислим интеграл:

$$\int_{0}^{1}(3t^2+3t^5)\,dt=\left[t^3+\frac{t^6}{2}\right]_{0}^{1}=1+\frac{1}{2}=\frac{3}{2}.$$

Таким образом, поток векторного поля через кривую равен $\frac{3}{2}$.

### Вычисление циркуляции векторного поля

Циркуляция векторного поля $\mathbf{F}(x, y, z)$ по замкнутой кривой $C$ можно вычислить с помощью криволинейного интеграла второго рода:

$$\Gamma=\oint_{C}\mathbf{F}\cdot d\mathbf{r}=\oint_{C}P\,dx+Q\,dy+R\,dz.$$

#### Пример

Рассмотрим пример вычисления циркуляции векторного поля $\mathbf{F}(x, y, z) = y\mathbf{i} + x\mathbf{j} + z\mathbf{k}$ по замкнутой кривой $C$, параметризованной как $(x(t), y(t), z(t)) = (\cos t, \sin t, t)$ для $t \in [0, 2\pi]$.

Сначала вычислим производные:

$$\frac{dx}{dt}=-\sin t,$$
$$\frac{dy}{dt}=\cos t,$$
$$\frac{dz}{dt}=1.$$

Теперь подставим все в формулу криволинейного интеграла второго рода:

$$\Gamma=\oint_{C}(y\frac{dx}{dt}+x\frac{dy}{dt}+z\frac{dz}{dt})\,dt=\int_{0}^{2\pi}(\sin t(-\sin t)+\cos t\cos t+t\cdot1)\,dt.$$

Упростим интеграл:

$$\int_{0}^{2\pi}(-\sin^2t+\cos^2t+t)\,dt=\int_{0}^{2\pi}(\cos 2t+t)\,dt.$$

Теперь вычислим интеграл:

$$\int_{0}^{2\pi}(\cos 2t+t)\,dt=\left[\frac{\sin 2t}{2}+\frac{t^2}{2}\right]_{0}^{2\pi}=0+\frac{(2\pi)^2}{2}=2\pi^2.$$

Таким образом, циркуляция векторного поля по замкнутой кривой равна $2\pi^2$.