## Приложения поверхностных интегралов первого рода
### Вычисление площади поверхности

Площадь поверхности $S$ можно вычислить с помощью поверхностного интеграла первого рода:

$$A=\iint_{S}dS.$$

Если поверхность $S$ параметризована как $(x(u, v), y(u, v), z(u, v))$ для $(u, v) \in D$, то площадь поверхности можно вычислить как:

$$A=\iint_{D}\sqrt{EG-F^2}\,du\,dv,$$

где $E$, $G$ и $F$ — коэффициенты первой квадратичной формы поверхности:

$$E=\left(\frac{\partial x}{\partial u}\right)^2+\left(\frac{\partial y}{\partial u}\right)^2+\left(\frac{\partial z}{\partial u}\right)^2,$$
$$G=\left(\frac{\partial x}{\partial v}\right)^2+\left(\frac{\partial y}{\partial v}\right)^2+\left(\frac{\partial z}{\partial v}\right)^2,$$
$$F=\frac{\partial x}{\partial u}\frac{\partial x}{\partial v}+\frac{\partial y}{\partial u}\frac{\partial y}{\partial v}+\frac{\partial z}{\partial u}\frac{\partial z}{\partial v}.$$

#### Пример

Рассмотрим пример вычисления площади поверхности, заданной уравнением $z = x^2 + y^2$ над кругом радиуса $R$, центрированного в начале координат. В полярных координатах $(r, \theta)$ область $D$ описывается как $0 \leq r \leq R$ и $0 \leq \theta \leq 2\pi$.

Сначала параметризуем поверхность:

$$x=r\cos\theta,$$
$$y=r\sin\theta,$$
$$z=r^2.$$

Теперь вычислим коэффициенты первой квадратичной формы:

$$E=\left(\frac{\partial x}{\partial r}\right)^2+\left(\frac{\partial y}{\partial r}\right)^2+\left(\frac{\partial z}{\partial r}\right)^2=(\cos\theta)^2+(\sin\theta)^2+(2r)^2=1+4r^2,$$
$$G=\left(\frac{\partial x}{\partial\theta}\right)^2+\left(\frac{\partial y}{\partial\theta}\right)^2+\left(\frac{\partial z}{\partial\theta}\right)^2=(-r\sin\theta)^2+(r\cos\theta)^2+0=r^2,$$
$$F=\frac{\partial x}{\partial r}\frac{\partial x}{\partial\theta}+\frac{\partial y}{\partial r}\frac{\partial y}{\partial\theta}+\frac{\partial z}{\partial r}\frac{\partial z}{\partial\theta}=0.$$

Теперь подставим все в формулу поверхностного интеграла:

$$A=\iint_{D}\sqrt{1+4r^2}r\,dr\,d\theta=\int_{0}^{2\pi}\int_{0}^{R}\sqrt{1+4r^2}r\,dr\,d\theta.$$

Вычислим внутренний интеграл:

$$\int_{0}^{R}\sqrt{1+4r^2}r\,dr.$$

Для вычисления этого интеграла можно использовать численные методы или специальные функции.

### Вычисление массы поверхности

Масса поверхности $S$ с плотностью $\rho(x, y, z)$ можно вычислить с помощью поверхностного интеграла первого рода:

$$M=\iint_{S}\rho(x,y,z)\,dS.$$

#### Пример

Рассмотрим пример вычисления массы поверхности, заданной уравнением $z = x^2 + y^2$ над кругом радиуса $R$, центрированного в начале координат, с плотностью $\rho(x, y, z) = 1$. В полярных координатах $(r, \theta)$ область $D$ описывается как $0 \leq r \leq R$ и $0 \leq \theta \leq 2\pi$.

Сначала параметризуем поверхность:

$$x=r\cos\theta,$$
$$y=r\sin\theta,$$
$$z=r^2.$$

Теперь вычислим коэффициенты первой квадратичной формы:

$$E=1+4r^2,$$
$$G=r^2,$$
$$F=0.$$

Теперь подставим все в формулу поверхностного интеграла:

$$M=\iint_{D}\sqrt{1+4r^2}r\,dr\,d\theta=\int_{0}^{2\pi}\int_{0}^{R}\sqrt{1+4r^2}r\,dr\,d\theta.$$

Вычислим внутренний интеграл:

$$\int_{0}^{R}\sqrt{1+4r^2}r\,dr.$$

Для вычисления этого интеграла можно использовать численные методы или специальные функции.

### Вычисление центра масс поверхности

Координаты центра масс поверхности $S$ с плотностью $\rho(x, y, z)$ можно вычислить с помощью поверхностных интегралов первого рода:

$$x_c=\frac{\iint_{S}x\rho(x,y,z)\,dS}{\iint_{S}\rho(x,y,z)\,dS},$$
$$y_c=\frac{\iint_{S}y\rho(x,y,z)\,dS}{\iint_{S}\rho(x,y,z)\,dS},$$
$$z_c=\frac{\iint_{S}z\rho(x,y,z)\,dS}{\iint_{S}\rho(x,y,z)\,dS}.$$

### Вычисление моментов инерции поверхности

Моменты инерции поверхности $S$ относительно осей $x$, $y$ и $z$ можно вычислить с помощью поверхностных интегралов первого рода:

$$I_x=\iint_{S}(y^2+z^2)\rho(x,y,z)\,dS,$$
$$I_y=\iint_{S}(x^2+z^2)\rho(x,y,z)\,dS,$$
$$I_z=\iint_{S}(x^2+y^2)\rho(x,y,z)\,dS.$$

#### Пример

Рассмотрим пример вычисления момента инерции поверхности, заданной уравнением $z = x^2 + y^2$ над кругом радиуса $R$, центрированного в начале координат, с плотностью $\rho(x, y, z) = 1$. В полярных координатах $(r, \theta)$ область $D$ описывается как $0 \leq r \leq R$ и $0 \leq \theta \leq 2\pi$.

Сначала параметризуем поверхность:

$$x=r\cos\theta,$$
$$y=r\sin\theta,$$
$$z=r^2.$$

Теперь вычислим коэффициенты первой квадратичной формы:

$$E=1+4r^2,$$
$$G=r^2,$$
$$F=0.$$

Теперь подставим все в формулу поверхностного интеграла для момента инерции относительно оси $z$:

$$I_z=\iint_{S}(x^2+y^2)\rho(x,y,z)\,dS=\iint_{D}(r^2\cos^2\theta+r^2\sin^2\theta)\sqrt{1+4r^2}r\,dr\,d\theta.$$

Упростим интеграл:

$$\iint_{D}r^2\sqrt{1+4r^2}r\,dr\,d\theta=\int_{0}^{2\pi}\int_{0}^{R}r^3\sqrt{1+4r^2}\,dr\,d\theta.$$

Вычислим внутренний интеграл:

$$\int_{0}^{R}r^3\sqrt{1+4r^2}\,dr.$$

Для вычисления этого интеграла можно использовать численные методы или специальные функции.