##  Приложения поверхностных интегралов второго рода

### Вычисление потока векторного поля через поверхность

Поток векторного поля $\mathbf{F}(x, y, z) = P(x, y, z)\mathbf{i} + Q(x, y, z)\mathbf{j} + R(x, y, z)\mathbf{k}$ через поверхность $S$ можно вычислить с помощью поверхностного интеграла второго рода:

$$\Phi=\iint_{S}\mathbf{F}\cdot d\mathbf{S}=\iint_{S}\mathbf{F}\cdot\mathbf{n}\,dS,$$

где $\mathbf{n}$ — единичный вектор нормали к поверхности $S$, а $d\mathbf{S} = \mathbf{n}\,dS$ — векторный элемент площади поверхности.

#### Пример

Рассмотрим пример вычисления потока векторного поля $\mathbf{F}(x, y, z) = x\mathbf{i} + y\mathbf{j} + z\mathbf{k}$ через поверхность $S$, заданную уравнением $z = x^2 + y^2$ над кругом радиуса $R$, центрированного в начале координат.

Сначала найдем нормаль к поверхности:

$$\mathbf{n}=\frac{\nabla(z-x^2-y^2)}{|\nabla(z-x^2-y^2)|}=\frac{(-2x)\mathbf{i}+(-2y)\mathbf{j}+\mathbf{k}}{\sqrt{1+4x^2+4y^2}}.$$

Теперь подставим все в формулу поверхностного интеграла второго рода:

$$\Phi=\iint_{S}\mathbf{F}\cdot\mathbf{n}\,dS=\iint_{D}(-2x^2-2y^2+z)\sqrt{1+4x^2+4y^2}\,dx\,dy,$$

где $D$ — круг радиуса $R$ на плоскости $xy$.

В полярных координатах $(r, \theta)$ область $D$ описывается как $0 \leq r \leq R$ и $0 \leq \theta \leq 2\pi$. Тогда:

$$\iint_{D}(-2x^2-2y^2+z)\sqrt{1+4x^2+4y^2}\,dx\,dy=\int_{0}^{2\pi}\int_{0}^{R}(-2r^2+r^2)\sqrt{1+4r^2}r\,dr\,d\theta.$$

Упростим интеграл:

$$\int_{0}^{2\pi}\int_{0}^{R}(-r^2)\sqrt{1+4r^2}r\,dr\,d\theta.$$

Теперь вычислим внутренний интеграл:

$$\int_{0}^{R}(-r^2)\sqrt{1+4r^2}r\,dr.$$

Для вычисления этого интеграла можно использовать численные методы или специальные функции.

### Вычисление силы, действующей на поверхность

Сила, действующая на поверхность $S$ под давлением $p(x, y, z)$, можно вычислить с помощью поверхностного интеграла второго рода:

$$\mathbf{F}=\iint_{S}p(x,y,z)\mathbf{n}\,dS,$$

где $\mathbf{n}$ — единичный вектор нормали к поверхности $S$.

#### Пример

Рассмотрим пример вычисления силы, действующей на поверхность $S$, заданную уравнением $z = x^2 + y^2$ над кругом радиуса $R$, центрированного в начале координат, под давлением $p(x, y, z) = 1$.

Сначала найдем нормаль к поверхности:

$$\mathbf{n}=\frac{(-2x)\mathbf{i}+(-2y)\mathbf{j}+\mathbf{k}}{\sqrt{1+4x^2+4y^2}}.$$

Теперь подставим все в формулу поверхностного интеграла второго рода:

$$\mathbf{F}=\iint_{S}p(x,y,z)\mathbf{n}\,dS=\iint_{D}\frac{(-2x)\mathbf{i}+(-2y)\mathbf{j}+\mathbf{k}}{\sqrt{1+4x^2+4y^2}}\sqrt{1+4x^2+4y^2}\,dx\,dy,$$

где $D$ — круг радиуса $R$ на плоскости $xy$.

В полярных координатах $(r, \theta)$ область $D$ описывается как $0 \leq r \leq R$ и $0 \leq \theta \leq 2\pi$. Тогда:

$$\iint_{D}((-2x)\mathbf{i}+(-2y)\mathbf{j}+\mathbf{k})\,dx\,dy=\int_{0}^{2\pi}\int_{0}^{R}((-2r\cos\theta)\mathbf{i}+(-2r\sin\theta)\mathbf{j}+\mathbf{k})r\,dr\,d\theta.$$

Упростим интеграл:

$$\int_{0}^{2\pi}\int_{0}^{R}((-2r^2\cos\theta)\mathbf{i}+(-2r^2\sin\theta)\mathbf{j}+\mathbf{k})\,dr\,d\theta.$$

Теперь вычислим внутренний интеграл:

$$\int_{0}^{R}((-2r^2\cos\theta)\mathbf{i}+(-2r^2\sin\theta)\mathbf{j}+\mathbf{k})\,dr.$$

Для вычисления этого интеграла можно использовать численные методы или специальные функции.